@@ -70,8 +70,8 @@
 #' \eqn{e^{NO}_{it}} in \cite{Touloumis (2016)}.}
 #' @author Anestis Touloumis
 #' @seealso \code{\link{rbin}} for simulating correlated binary responses,
-#' \code{\link{rmult.clm}} and \code{\link{rmult.crm}} for simulating
-#' correlated ordinal responses.
+#' \code{\link{rmult.clm}}, \code{\link{rmult.crm}} and
+#' \code{\link{rmult.acl}} for simulating correlated ordinal responses.
 #' @references Cario, M. C. and Nelson, B. L. (1997) \emph{Modeling and
 #' generating random vectors with arbitrary marginal distributions and
 #' correlation matrix}. Technical Report, Department of Industrial Engineering
@@ -94,39 +94,50 @@
 #' @examples
 #' ## See Example 3.1 in the Vignette.
 #' betas <- c(1, 3, 2, 1.25, 3.25, 1.75, 0.75, 2.75, 2.25, 0, 0, 0)
-#' N <- 500
-#' ncategories <- 4
-#' clsize <- 3
+#' sample_size <- 500
+#' categories_no <- 4
+#' cluster_size <- 3
 #' set.seed(1)
-#' x1 <- rep(rnorm(N), each = clsize)
-#' x2 <- rnorm(N * clsize)
+#' x1 <- rep(rnorm(sample_size), each = cluster_size)
+#' x2 <- rnorm(sample_size * cluster_size)
 #' xdata <- data.frame(x1, x2)
-#' cor.matrix <- kronecker(toeplitz(c(1, rep(0.95, clsize - 1))), diag(ncategories))
-#' CorNorRes <- rmult.bcl(clsize = clsize, ncategories = ncategories, betas = betas,
-#'     xformula = ~x1 + x2, xdata = xdata, cor.matrix = cor.matrix)
-#' suppressPackageStartupMessages(library('multgee'))
-#' fit <- nomLORgee(y ~ x1 + x2, data = CorNorRes$simdata, id = id, repeated = time,
-#'     LORstr = 'time.exch')
-#' round(coef(fit), 2)
-#'
+#' equicorrelation_matrix <- toeplitz(c(1, rep(0.95, cluster_size - 1)))
+#' identity_matrix <- diag(categories_no)
+#' latent_correlation_matrix <- kronecker(equicorrelation_matrix,
+#'   identity_matrix)
+#' simulated_nominal_dataset <- rmult.bcl(clsize = cluster_size,
+#'   ncategories = categories_no, betas = betas, xformula = ~ x1 + x2,
+#'   xdata = xdata, cor.matrix = latent_correlation_matrix)
+#' suppressPackageStartupMessages(library("multgee"))
+#' nominal_gee_model <- nomLORgee(y ~ x1 + x2,
+#'   data = simulated_nominal_dataset$simdata, id = id, repeated = time,
+#'   LORstr = "time.exch")
+#' round(coef(nominal_gee_model), 2)
 #' @export
-rmult.bcl <- function(clsize = clsize, ncategories = ncategories, betas = betas,
-    xformula = formula(xdata), xdata = parent.frame(), cor.matrix = cor.matrix,
-    rlatent = NULL) {
+rmult.bcl <- function(clsize = clsize, ncategories = ncategories, betas = betas, # nolint
+                      xformula = formula(xdata), xdata = parent.frame(), cor.matrix = cor.matrix, # nolint
+                      rlatent = NULL) {
   check_cluster_size(clsize)
-  ncategories <- check_ncategories(ncategories)
+  categories_no <- check_ncategories(ncategories)
   betas <- check_betas(betas, clsize)
-  lpformula <- check_xformula(xformula)
-  if (!is.environment(xdata))
-    xdata <- data.frame(na.omit(xdata))
-  lin_pred <- create_linear_predictor(betas, clsize, lpformula, xdata,
-                                      "rmult.bcl", ncategories = ncategories)
-  R <- nrow(lin_pred)
-  rlatent <- create_rlatent(rlatent, R, "cloglog", clsize, cor.matrix,
-                            "rmult.bcl", ncategories = ncategories)
-  Ysim <- apply_threshold(lin_pred, rlatent, clsize, "rmult.bcl",
-                          ncategories = ncategories)
-  lpformula <- update(lpformula, ~. - 1)
-  create_output(Ysim, R, clsize, rlatent, lpformula, xdata, "rmult.bcl",
-                ncategories = ncategories)
+  linear_predictor_formula <- check_xformula(xformula)
+  if (!is.environment(xdata)) xdata <- data.frame(na.omit(xdata))
+  linear_predictor <- create_linear_predictor(
+    betas, clsize, linear_predictor_formula, xdata, "rmult.bcl", categories_no
+  )
+  sample_size <- nrow(linear_predictor)
+  simulated_latent_responses <- create_rlatent(
+    rlatent, sample_size, "cloglog", clsize, cor.matrix, "rmult.bcl",
+    categories_no
+  )
+  simulated_nominal_responses <- apply_threshold(
+    linear_predictor, simulated_latent_responses, clsize, "rmult.bcl",
+    categories_no = categories_no
+  )
+  linear_predictor_formula <- update(linear_predictor_formula, ~ . - 1)
+  create_output(
+    simulated_nominal_responses, sample_size, clsize,
+    simulated_latent_responses, linear_predictor_formula, xdata, "rmult.bcl",
+    categories_no = categories_no
+  )
 }
